@@ -87,8 +87,6 @@ int main(int, char**)
             << get_defs(G_TYPE_VOLUME_MONITOR)
 
             // network IO classes
-            << get_defs(G_TYPE_DBUS_AUTH_OBSERVER)
-            << get_defs(G_TYPE_DBUS_SERVER)
             << get_defs(G_TYPE_INET_ADDRESS)
             << get_defs(G_TYPE_INET_SOCKET_ADDRESS)
             << get_defs(G_TYPE_SOCKET_ADDRESS)
@@ -110,6 +108,11 @@ int main(int, char**)
             << get_defs(G_TYPE_SOCKET_SERVICE)
             << get_defs(G_TYPE_THREADED_SOCKET_SERVICE)
 
+            // DBus classes.
+            << get_defs(G_TYPE_DBUS_AUTH_OBSERVER)
+            << get_defs(G_TYPE_DBUS_PROXY)
+            << get_defs(G_TYPE_DBUS_SERVER)
+
             << std::endl;
   
   return 0;
